OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "Info om prosessor er ikke tilgjengelig",
    "RAM: Total: {memTotalBytes}/Current usage: {memUsageBytes}" : "Minne: Totalt: {memTotalBytes}/Nåværende bruk: {memUsageBytes}",
    "RAM info not available" : "Info om minne er ikke tilgjengelig",
    "SWAP: Total: {swapTotalBytes}/Current usage: {swapUsageBytes}" : "SWAP: Totalt: {swapTotalBytes}/Nåværende bruk: {swapUsageBytes}",
    "SWAP info not available" : "Info om SWAP er ikke tilgjengelig",
    "Copied!" : "Kopiert!",
    "Not supported!" : "Ikke støttet!",
    "Press ⌘-C to copy." : "Trykk ⌘-C for å kopiere.",
    "Press Ctrl-C to copy." : "Trykk Ctrl-C for å kopiere.",
    "System" : "System",
    "Monitoring" : "Overvåker",
    "Monitoring app with useful server information" : "Overvåkingsapp med nyttig serverinformasjon",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Gir nyttig serverinformasjon, som CPU-belastning, RAM-bruk, diskbruk, antall brukere, ned mere.",
    "Operating System:" : "Operativsystem:",
    "CPU:" : "CPU:",
    "Memory:" : "Minne:",
    "Server time:" : "Servertid:",
    "Uptime:" : "Oppetid:",
    "Temperature" : "Temperatur",
    "Load" : "Last",
    "Memory" : "Minne",
    "Disk" : "Disk",
    "Mount:" : "Montering:",
    "Filesystem:" : "Filsystem:",
    "Size:" : "Størrelse:",
    "Available:" : "Tilgjengelig:",
    "Used:" : "Brukt:",
    "Files:" : "Filer:",
    "Storages:" : "Lagringer:",
    "Free Space:" : "Ledig plass:",
    "Network" : "Nettverk",
    "Hostname:" : "Servernavn:",
    "Gateway:" : "Standardruter:",
    "Status:" : "Status:",
    "Speed:" : "Hastighet:",
    "Duplex:" : "Duplex:",
    "MAC:" : "MAC:",
    "IPv4:" : "IPv4:",
    "IPv6:" : "IPv6:",
    "Active users" : "Aktive brukere",
    "Last hour" : "Siste time",
    "Shares" : "Delinger",
    "Users:" : "Brukere:",
    "Groups:" : "Grupper:",
    "Links:" : "Lenker:",
    "Emails:" : "E-poster:",
    "Federated sent:" : "Forent sendt:",
    "Federated received:" : "Forent mottatt:",
    "Talk conversations:" : "Talk-samtaler:",
    "PHP" : "PHP",
    "Version:" : "Versjon:",
    "Memory limit:" : "Minnegrense:",
    "Max execution time:" : "Maks. kjøringstid:",
    "Upload max size:" : "Maks. opplastingstørrelse:",
    "OPcache Revalidate Frequency:" : "OPcache Revalidate Frequency:",
    "Extensions:" : "Utvidelser:",
    "Unable to list extensions" : "Ikke i stand til å laste utvidelser",
    "Show phpinfo" : "Vis phpinfo",
    "Database" : "Database",
    "Type:" : "Type:",
    "External monitoring tool" : "Eksternt overvåkingsverktøy",
    "Use this end point to connect an external monitoring tool:" : "Bruk dette endepunktet til å koble til et eksternt overvåkingsverktøy:",
    "Copy" : "Kopier",
    "Output in JSON" : "Utdata i JSON",
    "Skip apps section (including apps section will send an external request to the app store)" : "Hopp over apper-delen (inkludert appdelen sender en ekstern forespørsel til appbutikken)",
    "Skip server update" : "Hopp over serveroppdatering",
    "To use an access token, please generate one then set it using the following command:" : "For å bruke et tilgangstoken, vennligst generer et og sett det ved hjelp av følgende kommando:",
    "Then pass the token with the \"NC-Token\" header when querying the above URL." : "Send deretter tokenet med \"NC-Token\"-overskriften under spørring av URL-adressen ovenfor.",
    "Unknown Processor" : "Ukjent prosessor"
},
"nplurals=2; plural=(n != 1);");
